@@ -39,7 +39,7 @@
  */
 
 #include "php.h"
-#if PHP_WIN32
+#ifdef PHP_WIN32
 #include "config.w32.h"
 #else
 #include <php_config.h>
